@@ -1,10 +1,11 @@
 package main
 
 import (
+	saferand "crypto/rand"
 	"encoding/json"
 	"fmt"
 	"io/ioutil"
-	"math/rand"
+	"math/big"
 	"os"
 	"strings"
 	"time"
@@ -42,20 +43,18 @@ const (
 )
 
 func generatePassword(length int) string {
-	rand.Seed(time.Now().UnixNano())
+
 	charset := upper + lower + digits
+	charsetLength := len(charset)
 
 	buf := make([]byte, length)
-	buf[0] = digits[rand.Intn(len(digits))]
-	buf[1] = upper[rand.Intn(len(upper))]
-	buf[2] = lower[rand.Intn(len(lower))]
-
-	for i := 3; i < length; i++ {
-		buf[i] = charset[rand.Intn(len(charset))]
+	for i := 0; i < length; i++ {
+		rInt, err := saferand.Int(saferand.Reader, big.NewInt(int64(charsetLength)))
+		if err != nil {
+			log.Fatalf("failed getting data from prng for password generation : %s", err)
+		}
+		buf[i] = charset[rInt.Int64()]
 	}
-	rand.Shuffle(len(buf), func(i, j int) {
-		buf[i], buf[j] = buf[j], buf[i]
-	})
 
 	return string(buf)
 }
@@ -214,7 +213,7 @@ cscli machines add MyTestMachine --password MyPassword
 			if err != nil {
 				log.Fatalf("unable to create machine: %s", err)
 			}
-			log.Infof("Machine '%s' created successfully", machineID)
+			log.Infof("Machine '%s' successfully added to the local API", machineID)
 
 			if apiURL == "" {
 				if csConfig.API.Client != nil && csConfig.API.Client.Credentials != nil && csConfig.API.Client.Credentials.URL != "" {
