@@ -9,13 +9,17 @@ import (
 // Buckets is the struct used to hold buckets in the context of
 // main.go the idea is to have one struct to rule them all
 type Buckets struct {
-	Bucket_map sync.Map
+	wgDumpState *sync.WaitGroup
+	wgPour      *sync.WaitGroup
+	Bucket_map  *sync.Map
 }
 
 // NewBuckets create the Buckets struct
 func NewBuckets() *Buckets {
 	return &Buckets{
-		Bucket_map: sync.Map{},
+		wgDumpState: &sync.WaitGroup{},
+		wgPour:      &sync.WaitGroup{},
+		Bucket_map:  &sync.Map{},
 	}
 }
 
