@@ -8,6 +8,7 @@ import (
 	"os"
 	"path/filepath"
 	"strings"
+	"sync"
 	"time"
 
 	"github.com/crowdsecurity/crowdsec/pkg/csconfig"
@@ -22,6 +23,7 @@ import (
 	"github.com/antonmedv/expr"
 	"github.com/antonmedv/expr/vm"
 	"github.com/goombaio/namegenerator"
+	"gopkg.in/tomb.v2"
 	yaml "gopkg.in/yaml.v2"
 
 	"github.com/crowdsecurity/crowdsec/pkg/exprhelpers"
@@ -66,6 +68,9 @@ type BucketFactory struct {
 	ScenarioVersion string                    `yaml:"version,omitempty"`
 	hash            string                    `yaml:"-"`
 	Simulated       bool                      `yaml:"simulated"` //Set to true if the scenario instanciating the bucket was in the exclusion list
+	tomb            *tomb.Tomb                `yaml:"-"`
+	wgPour          *sync.WaitGroup           `yaml:"-"`
+	wgDumpState     *sync.WaitGroup           `yaml:"-"`
 }
 
 func ValidateFactory(bucketFactory *BucketFactory) error {
@@ -122,7 +127,7 @@ func ValidateFactory(bucketFactory *BucketFactory) error {
 	return nil
 }
 
-func LoadBuckets(cscfg *csconfig.CrowdsecServiceCfg, files []string) ([]BucketFactory, chan types.Event, error) {
+func LoadBuckets(cscfg *csconfig.CrowdsecServiceCfg, files []string, tomb *tomb.Tomb, buckets *Buckets) ([]BucketFactory, chan types.Event, error) {
 	var (
 		ret      []BucketFactory = []BucketFactory{}
 		response chan types.Event
@@ -196,7 +201,9 @@ func LoadBuckets(cscfg *csconfig.CrowdsecServiceCfg, files []string) ([]BucketFa
 				}
 			}
 
-			err = LoadBucket(&bucketFactory)
+			bucketFactory.wgDumpState = buckets.wgDumpState
+			bucketFactory.wgPour = buckets.wgPour
+			err = LoadBucket(&bucketFactory, tomb)
 			if err != nil {
 				log.Errorf("Failed to load bucket %s : %v", bucketFactory.Name, err)
 				return nil, nil, fmt.Errorf("loading of %s failed : %v", bucketFactory.Name, err)
@@ -209,7 +216,7 @@ func LoadBuckets(cscfg *csconfig.CrowdsecServiceCfg, files []string) ([]BucketFa
 }
 
 /* Init recursively process yaml files from a directory and loads them as BucketFactory */
-func LoadBucket(bucketFactory *BucketFactory) error {
+func LoadBucket(bucketFactory *BucketFactory, tomb *tomb.Tomb) error {
 	var err error
 	if bucketFactory.Debug {
 		var clog = logrus.New()
@@ -322,6 +329,7 @@ func LoadBucket(bucketFactory *BucketFactory) error {
 	if err := ValidateFactory(bucketFactory); err != nil {
 		return fmt.Errorf("invalid bucket from %s : %v", bucketFactory.Filename, err)
 	}
+	bucketFactory.tomb = tomb
 	return nil
 
 }
@@ -362,13 +370,14 @@ func LoadBucketsState(file string, buckets *Buckets, bucketFactories []BucketFac
 				tbucket.In = make(chan types.Event)
 				tbucket.Mapkey = k
 				tbucket.Signal = make(chan bool, 1)
-				tbucket.KillSwitch = make(chan bool, 1)
 				tbucket.First_ts = v.First_ts
 				tbucket.Last_ts = v.Last_ts
 				tbucket.Ovflw_ts = v.Ovflw_ts
 				tbucket.Total_count = v.Total_count
 				buckets.Bucket_map.Store(k, tbucket)
-				go LeakRoutine(tbucket)
+				h.tomb.Go(func() error {
+					return LeakRoutine(tbucket)
+				})
 				<-tbucket.Signal
 				found = true
 				break
