@@ -3,6 +3,7 @@
 set -o pipefail
 #set -x
 
+
 RED='\033[0;31m'
 BLUE='\033[0;34m'
 GREEN='\033[0;32m'
@@ -30,7 +31,12 @@ LAPI_SECRETS="online_api_credentials.yaml"
 
 BIN_INSTALL_PATH="/usr/local/bin"
 CROWDSEC_BIN_INSTALLED="${BIN_INSTALL_PATH}/crowdsec"
-CSCLI_BIN_INSTALLED="${BIN_INSTALL_PATH}/cscli"
+
+if [[ -f "/usr/bin/cscli" ]] ; then
+    CSCLI_BIN_INSTALLED="/usr/bin/cscli"
+else
+    CSCLI_BIN_INSTALLED="${BIN_INSTALL_PATH}/cscli"
+fi
 
 ACQUIS_PATH="${CROWDSEC_CONFIG_PATH}"
 TMP_ACQUIS_FILE="tmp-acquis.yaml"
@@ -62,19 +68,26 @@ rm -rf $BACKUP_DIR
 log_info() {
     msg=$1
     date=$(date +%x:%X)
-    echo -e "[${date}][${BLUE}INF${NC}] crowdsec_wizard: ${msg}"
+    echo -e "${BLUE}INFO${NC}[${date}] crowdsec_wizard: ${msg}"
+}
+
+log_fatal() {
+    msg=$1
+    date=$(date +%x:%X)
+    echo -e "${RED}FATA${NC}[${date}] crowdsec_wizard: ${msg}" 1>&2 
+    exit 1
 }
 
 log_warn() {
     msg=$1
     date=$(date +%x:%X)
-    echo -e "[${date}][${ORANGE}WARN${NC}] crowdsec_wizard: ${msg}"
+    echo -e "${ORANGE}WARN${NC}[${date}] crowdsec_wizard: ${msg}"
 }
 
 log_err() {
     msg=$1
     date=$(date +%x:%X)
-    echo -e "[${date}][${RED}ERR${NC}] crowdsec_wizard: ${msg}" 1>&2
+    echo -e "${RED}ERR${NC}[${date}] crowdsec_wizard: ${msg}" 1>&2
 }
 
 log_dbg() {
@@ -93,19 +106,17 @@ detect_services () {
     #raw ps
     PSAX=`ps ax -o comm=`
     for SVC in ${SUPPORTED_SERVICES} ; do
-        log_info "Checking if service '${SVC}' is running (ps+systemd)"
+        log_dbg "Checking if service '${SVC}' is running (ps+systemd)"
         for SRC in "${SYSTEMD_SERVICES}" "${PSAX}" ; do
             echo ${SRC} | grep ${SVC} >/dev/null
             if [ $? -eq 0 ]; then
-    
                 #on centos, apache2 is named httpd                                                                                                                                                                                            
                 if [[ ${SVC} == "httpd" ]] ; then
                     SVC="apache2";
                 fi
-
                 DETECTED_SERVICES+=(${SVC})
                 HMENU+=(${SVC} "on")
-                log_info "Found '${SVC}' running"
+                log_dbg "Found '${SVC}' running"
                 break;
             fi;
         done;
@@ -124,9 +135,9 @@ detect_services () {
             log_err "user bailed out at services selection"
             exit 1;
         fi;
-        echo "Detected services (interactive) : ${DETECTED_SERVICES[@]}"
+        log_dbg "Detected services (interactive) : ${DETECTED_SERVICES[@]}"
     else
-        echo "Detected services (unattended) : ${DETECTED_SERVICES[@]}"
+        log_dbg "Detected services (unattended) : ${DETECTED_SERVICES[@]}"
     fi;
 }
 
@@ -173,7 +184,7 @@ find_logs_for() {
 	    candidates=`find "${path}" -type f -mtime -5 -ctime -5 -name "$fname"`
 	    #We have some candidates, add them
 	    for final_file in ${candidates} ; do
-	        log_info "Found logs file for '${SVC}': ${final_file}"
+	        log_dbg "Found logs file for '${SVC}': ${final_file}"
 	        DETECTED_LOGFILES+=(${final_file})
             HMENU+=(${final_file} "on")
 	    done;
@@ -261,15 +272,16 @@ genyaml() {
     echo "labels:"  >> ${TMP_ACQUIS_FILE}
     echo "  "${log_input_tags[${service}]}  >> ${TMP_ACQUIS_FILE}
     echo "---"  >> ${TMP_ACQUIS_FILE}
-    log_info "Acquisition file generated"
+    log_dbg "tmp acquisition file generated to: ${TMP_ACQUIS_FILE}"
 }
 
 genacquisition() {
-    log_info "Found following services : "${DETECTED_SERVICES[@]}
+    log_dbg "Found following services : "${DETECTED_SERVICES[@]}
     for PSVG in ${DETECTED_SERVICES[@]} ; do
         find_logs_for ${PSVG}
         if [[ ${#DETECTED_LOGFILES[@]} -gt 0 ]] ; then
-        	genyaml ${PSVG} ${DETECTED_LOGFILES[@]}
+            log_info "service '${PSVG}': ${DETECTED_LOGFILES[*]}"
+            genyaml ${PSVG} ${DETECTED_LOGFILES[@]}
         fi;
     done 
 }
@@ -299,47 +311,44 @@ check_cs_version () {
     NEW_PATCH_VERSION=$(echo $NEW_CS_VERSION | cut -d'.' -f3)
 
     if [[ $NEW_MAJOR_VERSION -gt $CURRENT_MAJOR_VERSION ]]; then
-        log_warn "new version ($NEW_CS_VERSION) is a major, you need to follow documentation to upgrade !"
-        echo ""
-        echo "Please follow : https://docs.crowdsec.net/Crowdsec/v1/migration/"
         if [[ ${FORCE_MODE} == "false" ]]; then
+            log_warn "new version ($NEW_CS_VERSION) is a major, you need to follow documentation to upgrade !"
+            echo ""
+            echo "Please follow : https://docs.crowdsec.net/Crowdsec/v1/migration/"
             exit 1
         fi
     elif [[ $NEW_MINOR_VERSION -gt $CURRENT_MINOR_VERSION ]] ; then
         log_warn "new version ($NEW_CS_VERSION) is a minor upgrade !"
-
         if [[ $ACTION != "upgrade" ]] ; then 
-            echo ""
-            echo "We recommand to upgrade with : sudo ./wizard.sh --upgrade "
-            echo "If you want to $ACTION anyway, please use '--force'."
-            echo ""
-            echo "Run : sudo ./wizard.sh --$ACTION --force"
             if [[ ${FORCE_MODE} == "false" ]]; then
+                echo ""
+                echo "We recommand to upgrade with : sudo ./wizard.sh --upgrade "
+                echo "If you want to $ACTION anyway, please use '--force'."
+                echo ""
+                echo "Run : sudo ./wizard.sh --$ACTION --force"
                 exit 1
             fi
         fi
     elif [[ $NEW_PATCH_VERSION -gt $CURRENT_PATCH_VERSION ]] ; then
         log_warn "new version ($NEW_CS_VERSION) is a patch !"
-
         if [[ $ACTION != "binupgrade" ]] ; then 
-            echo ""
-            echo "We recommand to upgrade binaries only : sudo ./wizard.sh --binupgrade "
-            echo "If you want to $ACTION anyway, please use '--force'."
-            echo ""
-            echo "Run : sudo ./wizard.sh --$ACTION --force"
             if [[ ${FORCE_MODE} == "false" ]]; then
+                echo ""
+                echo "We recommand to upgrade binaries only : sudo ./wizard.sh --binupgrade "
+                echo "If you want to $ACTION anyway, please use '--force'."
+                echo ""
+                echo "Run : sudo ./wizard.sh --$ACTION --force"
                 exit 1
             fi
         fi
     elif [[ $NEW_MINOR_VERSION -eq $CURRENT_MINOR_VERSION ]]; then
         log_warn "new version ($NEW_CS_VERSION) is same as current version ($CURRENT_CS_VERSION) !"
-
-        echo ""
-        echo "We recommand to $ACTION only if it's an higher version. "
-        echo "If it's an RC version (vX.X.X-rc) you can upgrade it using '--force'."
-        echo ""
-        echo "Run : sudo ./wizard.sh --$ACTION --force"
         if [[ ${FORCE_MODE} == "false" ]]; then
+            echo ""
+            echo "We recommand to $ACTION only if it's an higher version. "
+            echo "If it's an RC version (vX.X.X-rc) you can upgrade it using '--force'."
+            echo ""
+            echo "Run : sudo ./wizard.sh --$ACTION --force"
             exit 1
         fi
     fi
@@ -357,21 +366,22 @@ install_crowdsec() {
     #tmp
     mkdir -p /tmp/data
     mkdir -p /etc/crowdsec/hub/
-    install -v -m 600 -D "./config/${CLIENT_SECRETS}" "${CROWDSEC_CONFIG_PATH}" || exit
-    install -v -m 600 -D "./config/${LAPI_SECRETS}" "${CROWDSEC_CONFIG_PATH}" || exit
+    install -v -m 600 -D "./config/${CLIENT_SECRETS}" "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
+    install -v -m 600 -D "./config/${LAPI_SECRETS}" "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
 
     ## end tmp
 
-    install -v -m 644 -D ./config/config.yaml "${CROWDSEC_CONFIG_PATH}" || exit
-    install -v -m 644 -D ./config/dev.yaml "${CROWDSEC_CONFIG_PATH}" || exit
-    install -v -m 644 -D ./config/user.yaml "${CROWDSEC_CONFIG_PATH}" || exit
-    install -v -m 644 -D ./config/acquis.yaml "${CROWDSEC_CONFIG_PATH}" || exit
-    install -v -m 644 -D ./config/profiles.yaml "${CROWDSEC_CONFIG_PATH}" || exit
-    install -v -m 644 -D ./config/simulation.yaml "${CROWDSEC_CONFIG_PATH}" || exit
+    install -v -m 644 -D ./config/config.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
+    install -v -m 644 -D ./config/dev.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
+    install -v -m 644 -D ./config/user.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
+    install -v -m 644 -D ./config/acquis.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
+    install -v -m 644 -D ./config/profiles.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
+    install -v -m 644 -D ./config/simulation.yaml "${CROWDSEC_CONFIG_PATH}" 1> /dev/null || exit
+
     mkdir -p ${PID_DIR} || exit
-    PID=${PID_DIR} DATA=${CROWDSEC_DATA_DIR} CFG=${CROWDSEC_CONFIG_PATH} envsubst '$CFG $PID $DATA' < ./config/user.yaml > ${CROWDSEC_CONFIG_PATH}"/user.yaml"
+    PID=${PID_DIR} DATA=${CROWDSEC_DATA_DIR} CFG=${CROWDSEC_CONFIG_PATH} envsubst '$CFG $PID $DATA' < ./config/user.yaml > ${CROWDSEC_CONFIG_PATH}"/user.yaml" || log_fatal "unable to generate user configuration file"
     if [[ ${DOCKER_MODE} == "false" ]]; then
-        CFG=${CROWDSEC_CONFIG_PATH} PID=${PID_DIR} BIN=${CROWDSEC_BIN_INSTALLED} envsubst '$CFG $PID $BIN' < ./config/crowdsec.service > "${SYSTEMD_PATH_FILE}"
+        CFG=${CROWDSEC_CONFIG_PATH} PID=${PID_DIR} BIN=${CROWDSEC_BIN_INSTALLED} envsubst '$CFG $PID $BIN' < ./config/crowdsec.service > "${SYSTEMD_PATH_FILE}" || log_fatal "unable to crowdsec systemd file"
     fi
     install_bins
 
@@ -385,7 +395,7 @@ update_bins() {
     delete_bins
     install_bins
     log_info "Upgrade finished"
-    systemctl restart crowdsec
+    systemctl restart crowdsec || log_fatal "unable to restart crowdsec with systemctl"
 }
 
 update_full() {
@@ -415,13 +425,13 @@ update_full() {
         cp ${BACKUP_DIR}/crowdsec.db /var/lib/crowdsec/data/crowdsec.db
     fi
     log_info "Finished, restarting"
-    systemctl restart crowdsec || log_err "Failed to restart crowdsec"
+    systemctl restart crowdsec || log_fatal "Failed to restart crowdsec"
 }
 
 install_bins() {
-    log_info "Installing crowdsec binaries"
-    install -v -m 755 -D "${CROWDSEC_BIN}" "${CROWDSEC_BIN_INSTALLED}" || exit
-    install -v -m 755 -D "${CSCLI_BIN}" "${CSCLI_BIN_INSTALLED}" || exit
+    log_dbg "Installing crowdsec binaries"
+    install -v -m 755 -D "${CROWDSEC_BIN}" "${CROWDSEC_BIN_INSTALLED}" 1> /dev/null || exit
+    install -v -m 755 -D "${CSCLI_BIN}" "${CSCLI_BIN_INSTALLED}" 1> /dev/null || exit
     symlink_bins
 }
 
@@ -440,11 +450,25 @@ delete_bins() {
     rm -f ${CSCLI_BIN_INSTALLED}   
 }
 
+check_running_bouncers() {
+    #when uninstalling, check if user still has bouncers
+    BOUNCERS_COUNT=$(${CSCLI_BIN} bouncers list -o=json | jq '. | length')
+    if [[ ${BOUNCERS_COUNT} -gt 0 ]] ; then
+        if [[ ${FORCE_MODE} == "false" ]]; then
+            echo "WARNING : You have at least one bouncer registered (cscli bouncers list)."
+            echo "WARNING : Uninstalling crowdsec with a running bouncer will let it in an unpredictable state."
+            echo "WARNING : If you want to uninstall crowdsec, you should first uninstall the bouncers."
+            echo "Specify --force to bypass this restriction."
+            exit 1
+        fi;
+    fi
+}
+
 # uninstall crowdsec and cscli
 uninstall_crowdsec() {
-    systemctl stop crowdsec.service
-    systemctl disable crowdsec.service
-    ${CSCLI_BIN} dashboard remove -f -y
+    systemctl stop crowdsec.service 1>/dev/null
+    systemctl disable -q crowdsec.service 1>/dev/null
+    ${CSCLI_BIN} dashboard remove -f -y >/dev/null
     delete_bins
 
     # tmp
@@ -465,27 +489,31 @@ function show_link {
     echo ""
     echo "Useful links to start with Crowdsec:"
     echo ""
-    echo "  - Documentation : https://docs.crowdsec.net/"
+    echo "  - Documentation : https://docs.crowdsec.net/Crowdsec/v1/getting_started/crowdsec-tour/"
     echo "  - Crowdsec Hub  : https://hub.crowdsec.net/ "
     echo "  - Open issues   : https://github.com/crowdsecurity/crowdsec/issues"
     echo ""
+    echo "Useful commands to start with Crowdsec:"
+    echo ""
+    echo "  - sudo cscli metrics             : https://docs.crowdsec.net/Crowdsec/v1/cscli/cscli_metrics/"
+    echo "  - sudo cscli decisions list      : https://docs.crowdsec.net/Crowdsec/v1/cscli/cscli_decisions_list/"
+    echo "  - sudo cscli alerts list         : https://docs.crowdsec.net/Crowdsec/v1/cscli/cscli_alerts_list/"
+    echo "  - sudo cscli hub list            : https://docs.crowdsec.net/Crowdsec/v1/cscli/cscli_hub_list/"
+    echo ""
 }
 
 main() {
-    if [[ "$1" == "backup_to_dir" ]];
-    then
-        backup_to_dir
-        return
-    fi
-    
-    if [[ "$1" == "restore_from_dir" ]];
-    then
-        if ! [ $(id -u) = 0 ]; then
-            log_err "Please run the wizard as root or with sudo"
-            exit 1
+    if [ "$1" == "install" ] || [ "$1" == "configure" ]; then
+        if [ "${SILENT}" == "false" ]; then
+            which whiptail > /dev/null
+            if [ $? -ne 0 ]; then
+                log_fatal "whiptail binary is needed to use the wizard in interactive mode, exiting ..."
+            fi
+        fi
+        which envsubst > /dev/null
+        if [ $? -ne 0 ]; then
+            log_fatal "envsubst binary is needed to use do a full install with the wizard, exiting ..."
         fi
-        restore_from_dir
-        return
     fi
 
     if [[ "$1" == "binupgrade" ]];
@@ -510,12 +538,33 @@ main() {
         return
     fi
 
+    if [[ "$1" == "configure" ]];
+    then
+        if ! [ $(id -u) = 0 ]; then
+            log_err "Please run the wizard as root or with sudo"
+            exit 1
+        fi
+        detect_services
+        ${CSCLI_BIN_INSTALLED} hub update
+        install_collection
+        genacquisition
+        mv "${TMP_ACQUIS_FILE}" "${ACQUIS_TARGET}"
+
+        return
+    fi
+
+    if [[ "$1" == "noop" ]];
+    then
+        return
+    fi
+   
     if [[ "$1" == "uninstall" ]];
     then
         if ! [ $(id -u) = 0 ]; then
             log_err "Please run the wizard as root or with sudo"
             exit 1
         fi
+        check_running_bouncers
         uninstall_crowdsec
         return
     fi
@@ -541,12 +590,12 @@ main() {
             log_err "Please run the wizard as root or with sudo"
             exit 1
         fi
-        log_info "checking existing crowdsec install"
+        log_info "checking if crowdsec is installed"
         detect_cs_install
         ## Do make build before installing (as non--root) in order to have the binary and then install crowdsec as root
         log_info "installing crowdsec"
         install_crowdsec
-        log_info "configuring  ${CSCLI_BIN_INSTALLED}"
+        log_dbg "configuring ${CSCLI_BIN_INSTALLED}"
         ${CSCLI_BIN_INSTALLED} hub update > /dev/null 2>&1 || (log_err "fail to update crowdsec hub. exiting" && exit 1)
 
         # detect running services
@@ -559,27 +608,27 @@ main() {
         # Generate acquisition file and move it to the right folder
         genacquisition
         mv "${TMP_ACQUIS_FILE}" "${ACQUIS_TARGET}"
-
+        log_info "acquisition file path: ${ACQUIS_TARGET}"
         # Install collections according to detected services
-        log_info "Installing needed collections ..."
+        log_dbg "Installing needed collections ..."
         install_collection
 
         # install patterns/ folder
-        log_info "Installing patterns"
+        log_dbg "Installing patterns"
         mkdir -p "${PATTERNS_PATH}"
         cp "./${PATTERNS_FOLDER}/"* "${PATTERNS_PATH}/"
 
 
         # api register
-        ${CSCLI_BIN_INSTALLED} machines add --force "$(cat /etc/machine-id)" --password "$(cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w 32 | head -n 1)" -f "${CROWDSEC_CONFIG_PATH}/${CLIENT_SECRETS}"
-        log_info "Crowdsec LAPI registered"
+        ${CSCLI_BIN_INSTALLED} machines add --force "$(cat /etc/machine-id)" --password "$(cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w 32 | head -n 1)" -f "${CROWDSEC_CONFIG_PATH}/${CLIENT_SECRETS}" || log_fatal "unable to add machine to the local API"
+        log_dbg "Crowdsec LAPI registered" 
         
-        ${CSCLI_BIN_INSTALLED} capi register
-        log_info "Crowdsec CAPI registered"
+        ${CSCLI_BIN_INSTALLED} capi register || log_fatal "unable to register to the Central API"
+        log_dbg "Crowdsec CAPI registered" 
        
-        systemctl enable crowdsec
-        systemctl start crowdsec
-        log_info "Enabling and starting crowdsec daemon"
+        systemctl enable -q crowdsec >/dev/null || log_fatal "unable to enable crowdsec"
+        systemctl start crowdsec >/dev/null || log_fatal "unable to start crowdsec"
+        log_info "enabling and starting crowdsec daemon"
         show_link
         return
     fi
@@ -612,8 +661,7 @@ usage() {
       echo "    ./wizard.sh --upgrade                        Perform a full upgrade and try to migrate configs"
       echo "    ./wizard.sh --unattended                     Install in unattended mode, no question will be asked and defaults will be followed"
       echo "    ./wizard.sh --docker-mode                    Will install crowdsec without systemd and generate random machine-id"
-      echo "    ./wizard.sh -r|--restore                     Restore saved configurations from ${BACKUP_DIR} to ${CROWDSEC_CONFIG_PATH}"
-      echo "    ./wizard.sh -b|--backup                      Backup existing configurations to ${BACKUP_DIR}"
+      echo "    ./wizard.sh -n|--noop                        Do nothing"
 
       exit 0  
 }
@@ -651,18 +699,18 @@ do
         ACTION="bininstall"
         shift # past argument
         ;;
-    -b|--backup)
-        ACTION="backup_to_dir"
-        shift # past argument
-        ;;
-    -r|--restore)
-        ACTION="restore_from_dir"
+    -c|--configure)
+        ACTION="configure"
         shift # past argument
         ;;
     -d|--detect)
         ACTION="detect"
         shift # past argument
         ;;
+    -n|--noop)
+        ACTION="noop"
+        shift # past argument
+        ;;
     --unattended)
         SILENT="true"
         ACTION="install"
